.. _tutorials:

#########
Tutorials
#########

The pages in this section of the documentation are aimed at the newcomer to
django CMS. They're designed to help you get started quickly, and show how
easy it is to work with django CMS as a developer who wants to customise it and
get it working according to their own requirements.

These tutorials take you step-by-step through some key aspects of this work.
They're not intended to explain the :doc:`topics in depth </topics/index>`, or
provide :doc:`reference material </reference/index>`, but they will leave you
with a good idea of what is possible to achieve in just a few steps, and how
to go about it.

Once you're familiar with the basics presented in these tutorials, you'll find
the more in-depth coverage of the same topics in the :doc:`How-to
</how_to/index>` section.

The tutorials follow a logical progression, starting from installation of django CMS and the
creation of a brand new project, and build on each other, so it's recommended to work through them
in the order presented here.

.. toctree::
    :maxdepth: 1
    :numbered:

    01-install
    02-templates_placeholders
    03-integrating_applications
    04-plugins
    05-apphooks
    06-toolbar
    07-menu
    08-wizards
    09-third_party

If you want to install django CMS into an existing project, or prefer to configure django CMS by
hand, rather than using the automated installer, see :doc:`/how_to/install` and then follow the
rest of the tutorials.

Either way, you'll be able to find support and help from the numerous friendly members of the
django CMS community, either on our `Discourse forum <https://discourse.django-cms.org>`_ or `our
Slack group <https://www.django-cms.org/slack>`_.
